
#
# all rpm macros will be expanded during %include
#

function fix_qconfig_h {
   mv include/qconfig.h include/qconfig.h.orig
   sed -e '1i\
#ifndef SuSE_QCONFIG_ALREADY_INCLUDED \
#define SuSE_QCONFIG_ALREADY_INCLUDED 1 \
#define PLUGIN_PATH_EXTENSION "'$PLUGIN_PATH'" \
 ' -e s@${RPM_BUILD_ROOT}@/@ -e '$a\
#endif' include/qconfig.h.orig \
   > include/qconfig.h
  
}

function call_configure {
  EXTRA_OPTIONS=$@

  PLATFORM=linux-g++
  [ "$VERSION" -gt 820 ] && LARGEFILE="-largefile"
  [ "$VERSION" -gt 810 ] && XCURSOR="-xcursor"
  [ "$VERSION" -lt 720 ] && OPENGL="-disable-opengl" || OPENGL=""
  [ "$VERSION" -lt 800 ] && XFT="-no-xft -no-xrender " || XFT="-xft -xrender -I/usr/include/freetype2/ "
  [ "$VERSION" -lt 710 ] && XINERAMA="-no-xinerama " || XINERAMA="-xinerama "
  [ -e /usr/$WLIB/libmng.so ] && LIBMNG="-system-libmng -plugin-imgfmt-mng" || LIBMNG="-qt-libmng "
  [ -e /usr/X11R6/include/X11/extensions/XInput.h ] && TABLET="-tablet" || TABLET=""
  [ "$VERSION" -gt 720 ] && PGSQL="-plugin-sql-psql -I/usr/include -I/usr/include/pgsql/ -I/usr/include/pgsql/server" || PGSQL=""
  [ "$VERSION" -gt 710 ] && ODBC="-plugin-sql-odbc" || ODBC=""
  export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -fPIC"

  # workaround, to be removed later, yes, it is not nice
  [ "$HOSTTYPE" == "ppc64" ] && export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -mminimal-toc"
  [ "$HOSTTYPE" == "hppa" -o "$HOSTTYPE" == "parisc" ] && export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -ffunction-sections"
#  [ "$HOSTTYPE" == "x86_64" ] && export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -fno-if-conversion "

  PREFIX=/usr/lib/qt3/
  export LD_LIBRARY_PATH="/${PWD}/lib"
  ORACLE="/opt/oracle/product/8.1.6/rdbms/demo/"
  [ -d $ORACLE ] && \
    ORACLE="-plugin-sql-oci -I$ORACLE" || \
    ORACLE=""

  for i in mkspecs/linux-*/qmake.conf ; do
    sed \
-e "s,QMAKE_CFLAGS_RELEASE[\t ]*=.*,QMAKE_CFLAGS_RELEASE    = $RPM_OPT_FLAGS," \
-e "s,QMAKE_CFLAGS[\t ]*=.*,QMAKE_CFLAGS            = -pipe $RPM_OPT_FLAGS," \
-e "s,QMAKE_INCDIR[\t ]*=.*,QMAKE_INCDIR            = /usr/include/," \
-e "s,QMAKE_LIBDIR[\t ]*=.*,QMAKE_LIBDIR            = /usr/$WLIB/," \
-e "s,QMAKE_LIBDIR_X11[\t ]*=.*,QMAKE_LIBDIR_X11        = /usr/X11R6/$WLIB/," \
-e "s,QMAKE_LIBDIR_QT[\t ]*=.*,QMAKE_LIBDIR_QT         = \$(QTDIR)/$WLIB/," \
-e "s,QMAKE_INCDIR_OPENGL[\t ]*=.*,QMAKE_INCDIR_OPENGL     = /usr/include/," \
-e "s,QMAKE_LIBDIR_OPENGL[\t ]*=.*,QMAKE_LIBDIR_OPENGL     = /usr/$WLIB/," \
        $i > ${i}.new &&\
    mv ${i}.new $i
  done

# png is direct linked, other picture formats are loaded at runtime
  OPTIONS="-platform $PLATFORM -qt-gif -no-stl -release \
	   -system-zlib -system-libjpeg -system-libpng \
           -plugin-imgfmt-jpeg -nis -cups  \
	   -xkb $LIBMNG -no-g++-exceptions $LARGEFILE \
           $OPENGL $XFT $XINERAMA -sm -L/usr/$WLIB -L/usr/X11R6/$WLIB \
           -plugin-sql-mysql -I/usr/include/mysql/ \
           $TABLET $ORACLE $PGSQL $ODBC $NEWABI \
    	   -prefix $PREFIX -libdir $PREFIX/$WLIB"

# use styles as plugins, beside platinum. leave windowsxp disabled
# nice idea, but too many dumb apps have problems :(
#  for i in plugins/src/styles/* ; do
#     if [ -d $i -a ${i##*/} != "platinum" -a ${i##*/} != "windowsxp" ]
#        then OPTIONS="$OPTIONS -plugin-style-${i##*/}"
#     fi
#  done

  [ -e /usr/$WLIB/mysql/ ] && OPTIONS="$OPTIONS -L/usr/$WLIB/mysql/"
  
  export PATH=$PWD/bin:$PATH
  echo yes|./configure $OPTIONS $EXTRA_OPTIONS

# extent plugin buildkey on lib64 systems
   if [ "$WLIB" != "lib" ]; then
     mv include/qconfig.h include/qconfig.h.o
     sed -e 's,^\(#define QT_BUILD_KEY "[^"]*\)",\1 '$WLIB'",' \
        include/qconfig.h.o > include/qconfig.h
   fi

#
# workaround broken qmake from 3.2 beta1. to be removed later !
#
find . -name Makefile | while read i; do
  sed -e 's,/usr/lib[^/]*/libfreetype2.la,-lfreetype2,' \
      -e 's,/usr/lib[^/]*/libfreetype.la,-lfreetype,' \
      -e 's,/usr/lib[^/]*/libfontconfig.la,-lfontconfig,' \
      -e 's,/usr/lib[^/]*/libexpat.la,-lexpat,' \
      -e 's,/usr/lib[^/]*/libexpat.so.0,-lexpat,' \
      -e 's,/usr/lib[^/]*/libjpeg.la,-ljpeg,' \
      "$i" > "$i".new && \
  mv "$i".new "$i"
done

}

function post_install {
  find $1 -name \*.la | while read i; do
    sed -e 's,/usr/lib[^/]*/libfreetype2.la,-lfreetype2,' \
        -e 's,/usr/lib[^/]*/libfreetype.la,-lfreetype,' \
        -e 's,/usr/lib[^/]*/libfontconfig.la,-lfontconfig,' \
        -e 's,/usr/lib[^/]*/libexpat.la,-lexpat,' \
        -e 's,/usr/lib[^/]*/libexpat.so.0,-lexpat,' \
        -e 's,/usr/lib[^/]*/libjpeg.la,-ljpeg,' \
        "$i" > "$i".new && \
    mv "$i".new "$i"
  done
}

